@@ -190,6 +190,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         outdir: typing.Optional[builtins.str] = None,
+        post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         stack_traces: typing.Optional[builtins.bool] = None,
         tree_metadata: typing.Optional[builtins.bool] = None,
     ) -> "PDKNagApp":
@@ -201,6 +202,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
+        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The {@link AppProps.context} property This property is recommended over the {@link AppProps.context} property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         '''
@@ -211,6 +213,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
             auto_synth=auto_synth,
             context=context,
             outdir=outdir,
+            post_cli_context=post_cli_context,
             stack_traces=stack_traces,
             tree_metadata=tree_metadata,
         )
@@ -286,6 +289,7 @@ class PDKNagApp(
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         outdir: typing.Optional[builtins.str] = None,
+        post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         stack_traces: typing.Optional[builtins.bool] = None,
         tree_metadata: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -296,6 +300,7 @@ class PDKNagApp(
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
+        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The {@link AppProps.context} property This property is recommended over the {@link AppProps.context} property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         '''
@@ -306,6 +311,7 @@ class PDKNagApp(
             auto_synth=auto_synth,
             context=context,
             outdir=outdir,
+            post_cli_context=post_cli_context,
             stack_traces=stack_traces,
             tree_metadata=tree_metadata,
         )
@@ -369,6 +375,7 @@ class PDKNagApp(
         "auto_synth": "autoSynth",
         "context": "context",
         "outdir": "outdir",
+        "post_cli_context": "postCliContext",
         "stack_traces": "stackTraces",
         "tree_metadata": "treeMetadata",
         "fail_on_error": "failOnError",
@@ -383,6 +390,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         outdir: typing.Optional[builtins.str] = None,
+        post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         stack_traces: typing.Optional[builtins.bool] = None,
         tree_metadata: typing.Optional[builtins.bool] = None,
         fail_on_error: typing.Optional[builtins.bool] = None,
@@ -393,6 +401,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
+        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The {@link AppProps.context} property This property is recommended over the {@link AppProps.context} property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
@@ -406,6 +415,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
             check_type(argname="argument auto_synth", value=auto_synth, expected_type=type_hints["auto_synth"])
             check_type(argname="argument context", value=context, expected_type=type_hints["context"])
             check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
+            check_type(argname="argument post_cli_context", value=post_cli_context, expected_type=type_hints["post_cli_context"])
             check_type(argname="argument stack_traces", value=stack_traces, expected_type=type_hints["stack_traces"])
             check_type(argname="argument tree_metadata", value=tree_metadata, expected_type=type_hints["tree_metadata"])
             check_type(argname="argument fail_on_error", value=fail_on_error, expected_type=type_hints["fail_on_error"])
@@ -419,6 +429,8 @@ class PDKNagAppProps(aws_cdk.AppProps):
             self._values["context"] = context
         if outdir is not None:
             self._values["outdir"] = outdir
+        if post_cli_context is not None:
+            self._values["post_cli_context"] = post_cli_context
         if stack_traces is not None:
             self._values["stack_traces"] = stack_traces
         if tree_metadata is not None:
@@ -484,6 +496,42 @@ class PDKNagAppProps(aws_cdk.AppProps):
         result = self._values.get("outdir")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def post_cli_context(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
+        '''Additional context values for the application.
+
+        Context provided here has precedence over context set by:
+
+        - The CLI via --context
+        - The ``context`` key in ``cdk.json``
+        - The {@link AppProps.context} property
+
+        This property is recommended over the {@link AppProps.context} property since you
+        can make final decision over which context value to take in your app.
+
+        Context can be read from any construct using ``node.getContext(key)``.
+
+        :default: - no additional context
+
+        Example::
+
+            // context from the CLI and from `cdk.json` are stored in the
+            // CDK_CONTEXT env variable
+            const cliContext = JSON.parse(process.env.CDK_CONTEXT!);
+            
+            // determine whether to take the context passed in the CLI or not
+            const determineValue = process.env.PROD ? cliContext.SOMEKEY : 'my-prod-value';
+            new App({
+              postCliContext: {
+                SOMEKEY: determineValue,
+              },
+            });
+        '''
+        result = self._values.get("post_cli_context")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)
+
     @builtins.property
     def stack_traces(self) -> typing.Optional[builtins.bool]:
         '''Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs.
